@@ -5,7 +5,7 @@ use warnings;
 use strict;
 
 #######################################################################
-#  Acme::Pythonic::Functions is Copyright (C) 2009-2012, Hauke Lubenow.
+#  Acme::Pythonic::Functions is Copyright (C) 2009-2017, Hauke Lubenow.
 #
 #  This module is free software; you can redistribute it and/or modify it
 #  under the same terms as Perl 5.14.2.
@@ -29,9 +29,9 @@ use Exporter;
 our ($VERSION, @ISA, @EXPORT);
 @ISA         = qw(Exporter);
 
-$VERSION     = 0.38;
+$VERSION     = 0.39;
 
-@EXPORT      = qw(append endswith extend has_key insert isdigit isin isdir isfile len listdir lstrip lstrip2 oslistdir osname pront readfile remove replace rstrip rstrip2 startswith strip writefile);
+@EXPORT      = qw(append endswith extend has_key insert isdigit isin isdir isfile len listdir lstrip lstrip2 oslistdir osname pyprint readfile remove replace rstrip rstrip2 startswith strip writefile);
 
 # Internal Functions
 
@@ -59,13 +59,32 @@ sub checkArgs {
 
 # print-Replacement-Function
 
-sub pront {
+sub pyprint {
     if ($#_ == -1) {
-        @_ = ("");
+        return;
     }
-    for (@_) {
-        print"$_\n"
+    if ($#_ == 0) {
+        print ("$_[0]\n");
+        return;
     }
+    # Print the array similar to a (2D-)Python-list:
+    my @a = @_;
+    my $s;
+    my $i;
+    $s = "[";
+    for $i (0 .. $#a) {
+        if ($a[$i] =~ /[^0-9-]/) {
+            $s .= "\"$a[$i]\"";
+        } else {
+            $s .= $a[$i];
+        }
+        if ($i != $#a) {
+            $s .= ", ";
+        } else {
+            $s .= "]\n";
+        }
+    }
+    print $s;
 }
 
 # String-Functions
@@ -508,7 +527,7 @@ Acme::Pythonic::Functions - Python-like functions for Perl
 
 =head1 VERSION
 
-Version 0.38
+Version 0.39
 
 =head1 SYNOPSIS
 
@@ -516,99 +535,99 @@ The following script "example.pl" shows the usage of the functions. A ready-to-r
 
     use Acme::Pythonic::Functions;
     
-    pront "Strings:";
+    pyprint "Strings:";
     
     $a = "Hello";
     
     if (endswith($a, "ello")) {
-        pront '$a ends with "ello".';
+        pyprint '$a ends with "ello".';
     }
     
     if (isin($a, "ll", "s")) {
-        pront '"ll" is in $a.';
+        pyprint '"ll" is in $a.';
     }
     
     $a = "2345";
     
     if (isdigit($a)) {
-        pront '$a is a digit.';
+        pyprint '$a is a digit.';
     }
     
     $a = "    Line    ";
     
-    pront lstrip($a);
+    pyprint lstrip($a);
     $a = replace($a, "Line", "Another line");
-    pront $a;
-    pront rstrip($a);
+    pyprint $a;
+    pyprint rstrip($a);
     
     $a = "Hello";
     
     if (startswith($a, "He")) {
-        pront '$a starts with "He".';
+        pyprint '$a starts with "He".';
     }
     
-    pront len($a, "s");
+    pyprint len($a, "s");
     
-    pront;
-    pront "Lists:";
+    pyprint;
+    pyprint "Lists:";
     
     @a = ("a", "b", "c");
     $b = "d";
     
     @a = append(@a, $b);
     
-    pront @a;
+    pyprint @a;
     
     @a = ("a", "b", "c");
     @b = (1, 2, 3);
     
     @a = extend(@a, @b);
     
-    pront @a;
+    pyprint @a;
     
     if (isin(@a, "c", "l")) {
-        pront '"c" is in @a.';
+        pyprint '"c" is in @a.';
     }
     
     @a = insert(@a, 1, "a2");
     
-    pront @a;
+    pyprint @a;
     
-    pront len(@a, "l");
+    pyprint len(@a, "l");
     
     @a = remove(@a, "a2");
     
-    pront @a;
+    pyprint @a;
     
-    pront;
-    pront "Hashes:";
+    pyprint;
+    pyprint "Hashes:";
     
     %a = ("a" => 1, "b" => 2, "c" => 3);
     
     if (has_key(%a, "c")) {
-        pront '%a has a key "c".';
+        pyprint '%a has a key "c".';
     }
     
     if (isin(%a, "c", "h")) {
-        pront '%a has a key "c".';
+        pyprint '%a has a key "c".';
     }
     
-    pront;
-    pront "File-related:";
+    pyprint;
+    pyprint "File-related:";
     
     if (isdir("/home/user")) {
-        pront "Is directory.";
+        pyprint "Is directory.";
     }
     
     if (isfile("/home/user/myfile")) {
-        pront "Is file.";
+        pyprint "Is file.";
     }
     
     @a = ("a\n", "b\n", "c\n");
     
     if (isfile("test12345.txt")) {
     
-        pront 'File "test12345.txt" already exists. Nothing done.';
+        pyprint 'File "test12345.txt" already exists. Nothing done.';
     } else {
     
         writefile("test12345.txt", @a);
@@ -618,13 +637,13 @@ The following script "example.pl" shows the usage of the functions. A ready-to-r
             $i = rstrip($i);
             print $i . " " ;
         }
-        pront;
+        pyprint;
     }
 
-    pront oslistdir(".");
-    pront;
-    pront "System-related:";
-    pront osname();
+    pyprint oslistdir(".");
+    pyprint;
+    pyprint "System-related:";
+    pyprint osname();
     
 In the "examples"-directory mentioned above, there's also a a Pythonic-Perl-version of this script called "perlpyex.pl" and a corresponding Python-script called "pyex.py" for comparison.
 
@@ -636,10 +655,11 @@ The programming-language "Python" offers some basic string-, list- and other fun
 
 =over 12
 
-=item C<pront>
+=item C<pyprint>
 
 Python adds a (system-dependent) newline-character by default to strings to be printed.
-This is rather convenient and can be found in the say()-function of Perl 5.10 and above too. I wasn't happy with the way, say() prints lists though, because i want one element per line then. You can have that with something like 'say for @a;', but i wrote my own little print-replacement instead. It is called pront(). I think that's a funny name, a bit like chomp(), being derived from chop(). In Python, there isn't a function called pront() though.
+This is rather convenient and can be found in the say()-function of Perl 5.10 and above too. I wasn't happy with the way, say() prints lists though. You can have that with something like 'say for @a;', but I like the way, Python prints lists better. So I wrote my own little print-replacement called pyprint(). In Python, there isn't a function called pyprint().
+If you have to print more complex data-structures, use Data::Dumper.
 
 =back
 
@@ -815,7 +835,7 @@ Hauke Lubenow, <hlubenow2@gmx.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-Acme::Pythonic::Functions is Copyright (C) 2009-2012, Hauke Lubenow.
+Acme::Pythonic::Functions is Copyright (C) 2009-2017, Hauke Lubenow.
 
 This module is free software; you can redistribute it and/or modify it under the same terms as Perl 5.14.2.
 For more details, see the full text of the licenses in the directory LICENSES.
